## Inital ffysh package


To build the package : pip install build
                        python -m build

To upload the package : pip install twine
                        
                        python -m twine upload --repository pypi dist/*
